==> ui-framework-elements-4.9.10-sources.jar: gen/displays/items/GroupingToolbar1Mold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiItem from "alexandria-ui-elements/src/displays/components/Item";
import GroupingToolbar1MoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/ItemNotifier";
import GroupingToolbar1MoldRequester from "alexandria-ui-elements/gen/displays/requesters/ItemRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class GroupingToolbar1Mold extends UiItem {

	constructor(props) {
		super(props);
		this.notifier = new GroupingToolbar1MoldNotifier(this);
		this.requester = new GroupingToolbar1MoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<div style={{width:"100%",height:"100%",...this.props.style,...this.style(),...display}} className={className}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1994776681" mode="normal">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_549387944" layout="horizontal" spacing="16">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1585155376" format="description" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1377918510" label="age" format="description" mode="normal">
					</UiText>
				</UiBlock>
			</div>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(GroupingToolbar1Mold));
DisplayFactory.register("GroupingToolbar1Mold", withStyles(styles, { withTheme: true })(withSnackbar(GroupingToolbar1Mold)));

==> ui-framework-elements-4.25.21-sources.jar: gen/displays/items/GroupingToolbar1Mold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiItem from "alexandria-ui-elements/src/displays/components/Item";
import GroupingToolbar1MoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/ItemNotifier";
import GroupingToolbar1MoldRequester from "alexandria-ui-elements/gen/displays/requesters/ItemRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class GroupingToolbar1Mold extends UiItem {

	constructor(props) {
		super(props);
		this.notifier = new GroupingToolbar1MoldNotifier(this);
		this.requester = new GroupingToolbar1MoldRequester(this);
	};

	render() {
		const display = !this.state.visible ? {display:'none'} : undefined;
		const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<div style={{width:"100%",height:"100%",...this.props.style,...this.style(),...display}} className={className}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1994776681" mode="normal">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a10423720" layout="horizontal" spacing="16">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a10423720.a_1585155376" format="description" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a10423720.a_1377918510" label="age" format="description" mode="normal">
					</UiText>
				</UiBlock>
			</div>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(GroupingToolbar1Mold));
DisplayFactory.register("GroupingToolbar1Mold", withStyles(styles, { withTheme: true })(withSnackbar(GroupingToolbar1Mold)));
